@@ -166,6 +166,10 @@ impl<T: PolarsDataType> ChunkedArray<T> {
         self.bit_settings.contains(Settings::SORTED_DSC)
     }
 
+    pub fn unset_fast_explode_list(&mut self) {
+        self.bit_settings.remove(Settings::FAST_EXPLODE_LIST)
+    }
+
     pub fn is_sorted_flag2(&self) -> IsSorted {
         if self.is_sorted_flag() {
             IsSorted::Ascending
@@ -319,7 +323,12 @@ impl<T: PolarsDataType> ChunkedArray<T> {
     }
 
     /// Create a new ChunkedArray from self, where the chunks are replaced.
-    fn copy_with_chunks(&self, chunks: Vec<ArrayRef>, keep_sorted: bool) -> Self {
+    fn copy_with_chunks(
+        &self,
+        chunks: Vec<ArrayRef>,
+        keep_sorted: bool,
+        keep_fast_explode: bool,
+    ) -> Self {
         let mut out = ChunkedArray {
             field: self.field.clone(),
             chunks,
@@ -331,6 +340,9 @@ impl<T: PolarsDataType> ChunkedArray<T> {
         if !keep_sorted {
             out.set_sorted_flag(IsSorted::Not);
         }
+        if !keep_fast_explode {
+            out.unset_fast_explode_list()
+        }
         out
     }
 
@@ -390,7 +402,7 @@ impl<T: PolarsDataType> ChunkedArray<T> {
                 a.with_validity(validity)
             })
             .collect();
-        self.copy_with_chunks(chunks, true)
+        self.copy_with_chunks(chunks, true, false)
     }
 
     /// Get data type of ChunkedArray.
@@ -436,7 +448,7 @@ where
                     // safety:
                     // within bounds
                     debug_assert!((offset + len) <= array.len());
-                    let out = unsafe { array.slice_unchecked(offset, len) };
+                    let out = unsafe { array.sliced_unchecked(offset, len) };
                     offset += len;
                     out
                 })
@@ -496,6 +508,16 @@ where
             Err(PolarsError::ComputeError("no_slice".into()))
         }
     }
+    /// Contiguous mutable slice
+    pub(crate) fn cont_slice_mut(&mut self) -> Option<&mut [T::Native]> {
+        if self.chunks.len() == 1 && self.chunks[0].null_count() == 0 {
+            // Safety, we will not swap the PrimitiveArray.
+            let arr = unsafe { self.downcast_iter_mut().next().unwrap() };
+            arr.get_mut_values()
+        } else {
+            None
+        }
+    }
 
     /// Get slices of the underlying arrow data.
     /// NOTE: null values should be taken into account by the user of these slices as they are handled
