@@ -460,20 +460,6 @@ pub trait ChunkUnique<T: PolarsDataType> {
         self.arg_unique().map(|v| v.len())
     }
 
-    /// Get a mask of all the unique values.
-    fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-        Err(PolarsError::InvalidOperation(
-            "is_unique is not implemented for this dtype".into(),
-        ))
-    }
-
-    /// Get a mask of all the duplicated values.
-    fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-        Err(PolarsError::InvalidOperation(
-            "is_duplicated is not implemented for this dtype".into(),
-        ))
-    }
-
     /// The most occurring value(s). Can return multiple Values
     #[cfg(feature = "mode")]
     fn mode(&self) -> PolarsResult<ChunkedArray<T>> {
@@ -510,12 +496,12 @@ pub trait ChunkSort<T: PolarsDataType> {
     fn sort(&self, reverse: bool) -> ChunkedArray<T>;
 
     /// Retrieve the indexes needed to sort this array.
-    fn argsort(&self, options: SortOptions) -> IdxCa;
+    fn arg_sort(&self, options: SortOptions) -> IdxCa;
 
     /// Retrieve the indexes need to sort this and the other arrays.
-    fn argsort_multiple(&self, _other: &[Series], _reverse: &[bool]) -> PolarsResult<IdxCa> {
+    fn arg_sort_multiple(&self, _other: &[Series], _reverse: &[bool]) -> PolarsResult<IdxCa> {
         Err(PolarsError::InvalidOperation(
-            "argsort_multiple not implemented for this dtype".into(),
+            "arg_sort_multiple not implemented for this dtype".into(),
         ))
     }
 }
