@@ -161,20 +161,20 @@ macro_rules! impl_dyn_series {
             }
             fn divide(&self, _rhs: &Series) -> PolarsResult<Series> {
                 Err(PolarsError::ComputeError(
-                    "cannot do division on logical".into(),
+                    "Cannot divide Series of dtype: 'Date/Time'.".into(),
                 ))
             }
             fn remainder(&self, _rhs: &Series) -> PolarsResult<Series> {
                 Err(PolarsError::ComputeError(
-                    "cannot do remainder operation on logical".into(),
+                    "Cannot do remainder operation on Series of dtype: 'Date/Time'.".into(),
                 ))
             }
             fn group_tuples(&self, multithreaded: bool, sorted: bool) -> PolarsResult<GroupsProxy> {
                 self.0.group_tuples(multithreaded, sorted)
             }
             #[cfg(feature = "sort_multiple")]
-            fn argsort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
-                self.0.deref().argsort_multiple(by, reverse)
+            fn arg_sort_multiple(&self, by: &[Series], reverse: &[bool]) -> PolarsResult<IdxCa> {
+                self.0.deref().arg_sort_multiple(by, reverse)
             }
         }
 
@@ -355,8 +355,8 @@ macro_rules! impl_dyn_series {
                 self.0.sort_with(options).$into_logical().into_series()
             }
 
-            fn argsort(&self, options: SortOptions) -> IdxCa {
-                self.0.argsort(options)
+            fn arg_sort(&self, options: SortOptions) -> IdxCa {
+                self.0.arg_sort(options)
             }
 
             fn null_count(&self) -> usize {
@@ -379,14 +379,6 @@ macro_rules! impl_dyn_series {
                 self.0.arg_unique()
             }
 
-            fn arg_min(&self) -> Option<usize> {
-                self.0.arg_min()
-            }
-
-            fn arg_max(&self) -> Option<usize> {
-                self.0.arg_max()
-            }
-
             fn is_null(&self) -> BooleanChunked {
                 self.0.is_null()
             }
@@ -395,14 +387,6 @@ macro_rules! impl_dyn_series {
                 self.0.is_not_null()
             }
 
-            fn is_unique(&self) -> PolarsResult<BooleanChunked> {
-                self.0.is_unique()
-            }
-
-            fn is_duplicated(&self) -> PolarsResult<BooleanChunked> {
-                self.0.is_duplicated()
-            }
-
             fn reverse(&self) -> Series {
                 self.0.reverse().$into_logical().into_series()
             }
@@ -415,12 +399,6 @@ macro_rules! impl_dyn_series {
                 self.0.shift(periods).$into_logical().into_series()
             }
 
-            fn fill_null(&self, strategy: FillNullStrategy) -> PolarsResult<Series> {
-                self.0
-                    .fill_null(strategy)
-                    .map(|ca| ca.$into_logical().into_series())
-            }
-
             fn _sum_as_series(&self) -> Series {
                 Int32Chunked::full_null(self.name(), 1)
                     .cast(self.dtype())
@@ -503,11 +481,6 @@ macro_rules! impl_dyn_series {
                     _ => unreachable!(),
                 }
             }
-            #[cfg(feature = "is_first")]
-            fn is_first(&self) -> PolarsResult<BooleanChunked> {
-                self.0.is_first()
-            }
-
             #[cfg(feature = "mode")]
             fn mode(&self) -> PolarsResult<Series> {
                 self.0.mode().map(|ca| ca.$into_logical().into_series())
