@@ -866,13 +866,6 @@ pub(crate) fn index_to_chunked_index2(chunks: &[ArrayRef], index: usize) -> (usi
     (current_chunk_idx, index_remainder)
 }
 
-/// # SAFETY
-/// `dst` must be valid for `dst.len()` elements, and `src` and `dst` may not overlap.
-#[inline]
-pub(crate) unsafe fn copy_from_slice_unchecked<T>(src: &[T], dst: &mut [T]) {
-    std::ptr::copy_nonoverlapping(src.as_ptr(), dst.as_mut_ptr(), dst.len());
-}
-
 #[cfg(feature = "chunked_ids")]
 pub(crate) fn create_chunked_index_mapping(chunks: &[ArrayRef], len: usize) -> Vec<ChunkId> {
     let mut vals = Vec::with_capacity(len);
