@@ -191,7 +191,7 @@ impl<'a> CoreReader<'a> {
         to_cast: Vec<Field>,
         skip_rows_after_header: usize,
         row_count: Option<RowCount>,
-        parse_dates: bool,
+        try_parse_dates: bool,
     ) -> PolarsResult<CoreReader<'a>> {
         #[cfg(any(feature = "decompress", feature = "decompress-fast"))]
         let mut reader_bytes = reader_bytes;
@@ -230,7 +230,7 @@ impl<'a> CoreReader<'a> {
                         quote_char,
                         eol_char,
                         null_values.as_ref(),
-                        parse_dates,
+                        try_parse_dates,
                     )?;
                     Cow::Owned(inferred_schema)
                 }
