@@ -1,24 +1,18 @@
-#![cfg_attr(docsrs, feature(doc_cfg))]
+#![cfg_attr(docsrs, feature(doc_auto_cfg))]
 
 #[cfg(feature = "avro")]
-#[cfg_attr(docsrs, doc(cfg(feature = "avro")))]
 pub mod avro;
 #[cfg(feature = "async")]
 mod cloud;
 #[cfg(any(feature = "csv-file", feature = "json"))]
-#[cfg_attr(docsrs, doc(cfg(feature = "csv-file")))]
 pub mod csv;
 #[cfg(feature = "parquet")]
-#[cfg_attr(docsrs, doc(cfg(feature = "parquet")))]
 pub mod export;
 #[cfg(any(feature = "ipc", feature = "ipc_streaming"))]
-#[cfg_attr(docsrs, doc(cfg(any(feature = "ipc", feature = "ipc_streaming"))))]
 pub mod ipc;
 #[cfg(feature = "json")]
-#[cfg_attr(docsrs, doc(cfg(feature = "json")))]
 pub mod json;
 #[cfg(feature = "json")]
-#[cfg_attr(docsrs, doc(cfg(feature = "json")))]
 pub mod ndjson_core;
 #[cfg(feature = "async")]
 pub use crate::cloud::glob as async_glob;
@@ -32,7 +26,6 @@ pub use crate::cloud::glob as async_glob;
 pub mod mmap;
 mod options;
 #[cfg(feature = "parquet")]
-#[cfg_attr(docsrs, doc(cfg(feature = "feature")))]
 pub mod parquet;
 #[cfg(feature = "private")]
 pub mod predicates;
@@ -53,6 +46,7 @@ use std::path::{Path, PathBuf};
 use arrow::array::new_empty_array;
 use arrow::error::Result as ArrowResult;
 pub use options::*;
+use polars_core::config::verbose;
 use polars_core::frame::ArrowChunk;
 use polars_core::prelude::*;
 
@@ -142,7 +136,7 @@ pub(crate) fn finish_reader<R: ArrowReader>(
                     .iter()
                     .map(|df: &DataFrame| df.height())
                     .sum::<usize>();
-                if std::env::var("POLARS_VERBOSE").as_deref().unwrap_or("0") == "1" {
+                if verbose() {
                     eprintln!("sliced off {} rows of the 'DataFrame'. These lines were read because they were in a single chunk.", df.height() - n)
                 }
                 parsed_dfs.push(df.slice(0, len));
