@@ -2,13 +2,11 @@
 mod binary;
 #[cfg(feature = "interpolate")]
 mod interpolate;
-mod list;
+pub mod list;
 #[cfg(feature = "propagate_nans")]
 pub mod nan_propagating_aggregate;
 mod set;
 mod strings;
-#[cfg(feature = "to_dummies")]
-mod to_dummies;
 #[cfg(feature = "top_k")]
 mod top_k;
 
@@ -21,8 +19,6 @@ pub use list::*;
 use polars_core::prelude::*;
 pub use set::ChunkedSet;
 pub use strings::*;
-#[cfg(feature = "to_dummies")]
-pub use to_dummies::*;
 #[cfg(feature = "top_k")]
 pub use top_k::*;
 
