@@ -54,7 +54,13 @@ from polars.dependencies import numpy as np
 from polars.dependencies import pandas as pd
 from polars.dependencies import pyarrow as pa
 from polars.exceptions import ShapeError
-from polars.utils import _is_generator, arrlen, range_to_series, threadpool_size
+from polars.utils import (
+    _is_generator,
+    arrlen,
+    deprecated_alias,
+    range_to_series,
+    threadpool_size,
+)
 
 if version_info >= (3, 10):
 
@@ -256,13 +262,10 @@ def sequence_to_pyseries(
 
     # empty sequence
     if not values and dtype is None:
-        if dtype_if_empty:
-            # if dtype for empty sequence could be guessed
-            # (e.g comparisons between self and other)
-            dtype = dtype_if_empty
-        else:
-            # default to Float32 type
-            dtype = Float32
+        # if dtype for empty sequence could be guessed
+        # (e.g comparisons between self and other), default to Float32
+        dtype = dtype_if_empty or Float32
+
     # lists defer to subsequent handling; identify nested type
     elif dtype == List:
         nested_dtype = getattr(dtype, "inner", None)
@@ -294,7 +297,7 @@ def sequence_to_pyseries(
     # flat data
     if (
         dtype is not None
-        and dtype not in (Struct, Unknown)
+        and dtype not in (List, Struct, Unknown)
         and is_polars_dtype(dtype)
         and (python_dtype is None)
     ):
@@ -315,11 +318,8 @@ def sequence_to_pyseries(
         ).to_struct(name)
     else:
         if python_dtype is None:
-            if value is None:
-                # generic default dtype
-                python_dtype = float
-            else:
-                python_dtype = type(value)
+            # generic default dtype
+            python_dtype = float if value is None else type(value)
 
         # temporal branch
         if python_dtype in py_temporal_types:
@@ -333,7 +333,7 @@ def sequence_to_pyseries(
             if dtype == Datetime and value.tzinfo is not None:
                 py_series = PySeries.new_from_anyvalues(name, values)
                 tz = str(value.tzinfo)
-                return pli.wrap_s(py_series).dt.tz_localize(tz)._s
+                return pli.wrap_s(py_series).dt.replace_time_zone(tz)._s
 
             # TODO: use anyvalues here (no need to require pyarrow for this).
             arrow_dtype = dtype_to_arrow_type(dtype)
@@ -349,17 +349,23 @@ def sequence_to_pyseries(
                         type(nested_value) if nested_value is not None else float
                     )
 
-            # recursively call Series constructor
-            if nested_dtype == list:
-                return sequence_to_pyseries(
+            # recursively call Series constructor for nested types
+            if nested_dtype in (list, List, Struct):
+                s = sequence_to_pyseries(
                     name=name,
                     values=[
-                        sequence_to_pyseries(name, seq, dtype=None, strict=strict)
-                        for seq in values
+                        pli.Series(
+                            values=v,
+                            dtype=nested_dtype,  # type: ignore[arg-type]
+                            strict=strict,
+                            nan_to_null=nan_to_null,
+                        )
+                        for v in (values or [None])
                     ],
-                    dtype=None,
+                    nan_to_null=nan_to_null,
                     strict=strict,
                 )
+                return s if values else pli.Series._from_pyseries(s)[:0]._s
 
             # logs will show a panic if we infer wrong dtype and it's hard to error
             # from the rust side. to reduce the likelihood of this happening we
@@ -373,14 +379,14 @@ def sequence_to_pyseries(
                     for lst in values:
                         for vl in lst:
                             equal_to_inner = type(vl) == nested_dtype
-                            if not equal_to_inner or count > 50:
+                            if not equal_to_inner or count > N_INFER_DEFAULT:
                                 break
                             count += 1
                     if equal_to_inner:
                         dtype = py_type_to_dtype(nested_dtype)
                         with suppress(BaseException):
                             return PySeries.new_list(name, values, dtype)
-                # pass; we create an object if we get here
+                # pass; give up and create via "new_object" if we get here
             else:
                 try:
                     if is_polars_dtype(nested_dtype):
@@ -455,9 +461,10 @@ def sequence_to_pyseries(
                         raise error
 
 
+@deprecated_alias(nan_to_none="nan_to_null")
 def _pandas_series_to_arrow(
     values: pd.Series | pd.DatetimeIndex,
-    nan_to_none: bool = True,
+    nan_to_null: bool = True,
     min_len: int | None = None,
 ) -> pa.Array:
     """
@@ -467,7 +474,7 @@ def _pandas_series_to_arrow(
     ----------
     values : :class:`pandas.Series` or :class:`pandas.DatetimeIndex`
         Series to convert to arrow
-    nan_to_none : bool, default = True
+    nan_to_null : bool, default = True
         Interpret `NaN` as missing values
     min_len : int, optional
         in case of null values, this length will be used to create a dummy f64 array
@@ -482,12 +489,12 @@ def _pandas_series_to_arrow(
     if dtype == "object":
         first_non_none = _get_first_non_none(values.values)  # type: ignore[arg-type]
         if isinstance(first_non_none, str):
-            return pa.array(values, pa.large_utf8(), from_pandas=nan_to_none)
+            return pa.array(values, pa.large_utf8(), from_pandas=nan_to_null)
         elif first_non_none is None:
             return pa.nulls(min_len, pa.large_utf8())
-        return pa.array(values, from_pandas=nan_to_none)
+        return pa.array(values, from_pandas=nan_to_null)
     elif dtype:
-        return pa.array(values, from_pandas=nan_to_none)
+        return pa.array(values, from_pandas=nan_to_null)
     else:
         # Pandas Series is actually a Pandas DataFrame when the original dataframe
         # contains duplicated columns and a duplicated column is requested with df["a"].
@@ -497,15 +504,16 @@ def _pandas_series_to_arrow(
         )
 
 
+@deprecated_alias(nan_to_none="nan_to_null")
 def pandas_to_pyseries(
-    name: str, values: pd.Series | pd.DatetimeIndex, nan_to_none: bool = True
+    name: str, values: pd.Series | pd.DatetimeIndex, nan_to_null: bool = True
 ) -> PySeries:
     """Construct a PySeries from a pandas Series or DatetimeIndex."""
     # TODO: Change `if not name` to `if name is not None` once name is Optional[str]
     if not name and values.name is not None:
         name = str(values.name)
     return arrow_to_pyseries(
-        name, _pandas_series_to_arrow(values, nan_to_none=nan_to_none)
+        name, _pandas_series_to_arrow(values, nan_to_null=nan_to_null)
     )
 
 
@@ -601,7 +609,7 @@ def _unpack_schema(
     column_dtypes = {
         lookup.get(col[0], col[0]): col[1]
         for col in (schema or [])
-        if not isinstance(col, str) and col[1]
+        if not isinstance(col, str) and col[1] is not None
     }
     if schema_overrides:
         column_dtypes.update(schema_overrides)
@@ -609,6 +617,9 @@ def _unpack_schema(
             column_names = column_names + [
                 col for col in column_dtypes if col not in column_names
             ]
+    for col, dtype in column_dtypes.items():
+        if not is_polars_dtype(dtype, include_unknown=True) and dtype is not None:
+            column_dtypes[col] = py_type_to_dtype(dtype)
 
     return (
         column_names or None,  # type: ignore[return-value]
@@ -620,8 +631,9 @@ def _expand_dict_scalars(
     data: Mapping[str, Sequence[object] | Mapping[str, Sequence[object]] | pli.Series],
     schema_overrides: SchemaDict | None = None,
     order: Sequence[str] | None = None,
+    nan_to_null: bool = False,
 ) -> dict[str, pli.Series]:
-    """Expand scalar values in dict data (propagate literal as array)."""
+    """Expand any scalar values in dict data (propagate literal as array)."""
     updated_data = {}
     if data:
         dtypes = schema_overrides or {}
@@ -633,7 +645,9 @@ def _expand_dict_scalars(
                     updated_data[name] = pli.DataFrame(val).to_struct(name)
 
                 elif arrlen(val) is not None or _is_generator(val):
-                    updated_data[name] = pli.Series(name=name, values=val, dtype=dtype)
+                    updated_data[name] = pli.Series(
+                        name=name, values=val, dtype=dtype, nan_to_null=nan_to_null
+                    )
 
                 elif val is None or isinstance(  # type: ignore[redundant-expr]
                     val, (int, float, str, bool)
@@ -668,64 +682,70 @@ def dict_to_pydf(
     data: Mapping[str, Sequence[object] | Mapping[str, Sequence[object]] | pli.Series],
     schema: SchemaDefinition | None = None,
     schema_overrides: SchemaDict | None = None,
+    nan_to_null: bool = False,
 ) -> PyDataFrame:
     """Construct a PyDataFrame from a dictionary of sequences."""
-    if not schema:
-        schema = list(data)
-    if schema:
-        # the columns arg may also set the dtype/column order of the series
-        if isinstance(schema, dict) and data:
-            if not all((col in schema) for col in data):
-                raise ValueError(
-                    "The given column-schema names do not match the data dictionary"
-                )
-            data = {col: data[col] for col in schema}
+    if isinstance(schema, dict) and data:
+        if not all((col in schema) for col in data):
+            raise ValueError(
+                "The given column-schema names do not match the data dictionary"
+            )
+        data = {col: data[col] for col in schema}
 
-        columns, schema_overrides = _unpack_schema(
-            schema, lookup_names=data.keys(), schema_overrides=schema_overrides
-        )
-        if not data and schema_overrides:
-            data_series = [
-                pli.Series(name, [], schema_overrides.get(name))._s for name in columns
-            ]
-        else:
-            data_series = [
-                s._s for s in _expand_dict_scalars(data, schema_overrides).values()
-            ]
+    column_names, schema_overrides = _unpack_schema(
+        schema, lookup_names=data.keys(), schema_overrides=schema_overrides
+    )
+    if not column_names:
+        column_names = list(data)
 
-        data_series = _handle_columns_arg(data_series, columns=columns, from_dict=True)
-        return PyDataFrame(data_series)
-
-    if _NUMPY_AVAILABLE:
-        count_numpy = 0
-        for val in data.values():
-            # only start a thread pool from a reasonable size.
-            count_numpy += int(
+    if data and _NUMPY_AVAILABLE:
+        # if there are 3 or more numpy arrays of sufficient size, we multi-thread:
+        count_numpy = sum(
+            int(
                 _check_for_numpy(val)
                 and isinstance(val, np.ndarray)
                 and len(val) > 1000
             )
+            for val in data.values()
+        )
+        if count_numpy >= 3:
+            # yes, multi-threading was easier in python here; we cannot have multiple
+            # threads running python and release the gil in pyo3 (it will deadlock).
 
-        # if we have more than 3 numpy arrays we multi-thread
-        if count_numpy > 2:
-            # yes, multi-threading was easier in python here
-            # we cannot run multiple threads that run python code
-            # and release the gil in pyo3
-            # it will deadlock.
-
-            # dummy is threaded
+            # (note: 'dummy' is threaded)
             import multiprocessing.dummy
 
             pool_size = threadpool_size()
             with multiprocessing.dummy.Pool(pool_size) as pool:
-                data_series = pool.map(
-                    lambda t: pli.Series(t[0], t[1])._s,
-                    [(k, v) for k, v in data.items()],
+                data = dict(
+                    zip(
+                        column_names,
+                        pool.map(
+                            lambda t: pli.Series(t[0], t[1])
+                            if isinstance(t[1], np.ndarray)
+                            else t[1],
+                            [(k, v) for k, v in data.items()],
+                        ),
+                    )
                 )
-            return PyDataFrame(data_series)
 
-    data = _expand_dict_scalars(data)
-    return PyDataFrame.read_dict(data)
+    if not data and schema_overrides:
+        data_series = [
+            pli.Series(
+                name, [], dtype=schema_overrides.get(name), nan_to_null=nan_to_null
+            )._s
+            for name in column_names
+        ]
+    else:
+        data_series = [
+            s._s
+            for s in _expand_dict_scalars(
+                data, schema_overrides, nan_to_null=nan_to_null
+            ).values()
+        ]
+
+    data_series = _handle_columns_arg(data_series, columns=column_names, from_dict=True)
+    return PyDataFrame(data_series)
 
 
 def sequence_to_pydf(
@@ -763,12 +783,15 @@ def sequence_to_pydf(
         column_names, schema_overrides = _unpack_schema(
             schema, schema_overrides=schema_overrides
         )
-        dtypes = (
-            include_unknowns(schema_overrides, column_names)
+        dicts_schema = (
+            include_unknowns(schema_overrides, column_names or list(schema_overrides))
             if schema_overrides and column_names
             else None
         )
-        pydf = PyDataFrame.read_dicts(data, infer_schema_length, dtypes)
+        pydf = PyDataFrame.read_dicts(data, infer_schema_length, dicts_schema)
+
+        if column_names and set(column_names).intersection(pydf.columns()):
+            column_names = None
         if column_names or schema_overrides:
             pydf = _post_apply_columns(
                 pydf,
@@ -777,10 +800,16 @@ def sequence_to_pydf(
             )
         return pydf
 
-    elif isinstance(data[0], (list, tuple, Sequence)) and not isinstance(data[0], str):
+    elif (
+        isinstance(data[0], (list, tuple, Sequence)) and not isinstance(data[0], str)
+    ) or (
+        _check_for_numpy(data[0])
+        and isinstance(data[0], np.ndarray)
+        and data[0].ndim == 1
+    ):
         if is_namedtuple(data[0]):
             if schema is None:
-                schema = data[0]._fields  # type: ignore[attr-defined]
+                schema = data[0]._fields  # type: ignore[union-attr]
                 if len(data[0].__annotations__) == len(schema):
                     schema = [
                         (name, py_type_to_dtype(tp, raise_unmatched=False))
@@ -915,6 +944,7 @@ def numpy_to_pydf(
     schema: SchemaDefinition | None = None,
     schema_overrides: SchemaDict | None = None,
     orient: Orientation | None = None,
+    nan_to_null: bool = False,
 ) -> PyDataFrame:
     """Construct a PyDataFrame from a numpy ndarray."""
     shape = data.shape
@@ -968,21 +998,31 @@ def numpy_to_pydf(
 
     elif len(shape) == 1:
         data_series = [
-            pli.Series(column_names[0], data, schema_overrides.get(column_names[0]))._s
+            pli.Series(
+                name=column_names[0],
+                values=data,
+                dtype=schema_overrides.get(column_names[0]),
+                nan_to_null=nan_to_null,
+            )._s
         ]
-
     else:
         if orient == "row":
             data_series = [
                 pli.Series(
-                    column_names[i], data[:, i], schema_overrides.get(column_names[i])
+                    name=column_names[i],
+                    values=data[:, i],
+                    dtype=schema_overrides.get(column_names[i]),
+                    nan_to_null=nan_to_null,
                 )._s
                 for i in range(n_columns)
             ]
         else:
             data_series = [
                 pli.Series(
-                    column_names[i], data[i], schema_overrides.get(column_names[i])
+                    name=column_names[i],
+                    values=data[i],
+                    dtype=schema_overrides.get(column_names[i]),
+                    nan_to_null=nan_to_null,
                 )._s
                 for i in range(n_columns)
             ]
@@ -1017,10 +1057,7 @@ def arrow_to_pydf(
     names = []
     for i, column in enumerate(data):
         # extract the name before casting
-        if column._name is None:
-            name = f"column_{i}"
-        else:
-            name = column._name
+        name = f"column_{i}" if column._name is None else column._name
         names.append(name)
 
         column = coerce_arrow(column)
@@ -1189,21 +1226,54 @@ def iterable_to_pydf(
     return (df.rechunk() if n_chunks > 0 else df)._df
 
 
+def pandas_has_default_index(df: pd.DataFrame) -> bool:
+    """Identify if the pandas frame only has a default (or equivalent) index."""
+    from pandas.core.indexes.numeric import IntegerIndex
+    from pandas.core.indexes.range import RangeIndex
+
+    index_cols = df.index.names
+
+    if len(index_cols) > 1 or index_cols not in ([None], [""]):
+        # not default: more than one index, or index is named
+        return False
+    elif df.index.equals(RangeIndex(start=0, stop=len(df), step=1)):
+        # is default: simple range index
+        return True
+    else:
+        # finally, is the index _equivalent_ to a default unnamed
+        # integer index with frame data that was previously sorted
+        return (
+            isinstance(df.index, IntegerIndex)
+            and (df.index.sort_values() == np.arange(len(df))).all()
+        )
+
+
+@deprecated_alias(nan_to_none="nan_to_null")
 def pandas_to_pydf(
     data: pd.DataFrame,
     schema: SchemaDefinition | None = None,
     schema_overrides: SchemaDict | None = None,
     rechunk: bool = True,
-    nan_to_none: bool = True,
+    nan_to_null: bool = True,
+    include_index: bool = False,
 ) -> PyDataFrame:
     """Construct a PyDataFrame from a pandas DataFrame."""
+    arrow_dict = {}
     length = data.shape[0]
-    arrow_dict = {
-        str(col): _pandas_series_to_arrow(
-            data[col], nan_to_none=nan_to_none, min_len=length
+
+    if include_index and not pandas_has_default_index(data):
+        for idxcol in data.index.names:
+            arrow_dict[str(idxcol)] = _pandas_series_to_arrow(
+                data.index.get_level_values(idxcol),
+                nan_to_null=nan_to_null,
+                min_len=length,
+            )
+
+    for col in data.columns:
+        arrow_dict[str(col)] = _pandas_series_to_arrow(
+            data[col], nan_to_null=nan_to_null, min_len=length
         )
-        for col in data.columns
-    }
+
     arrow_table = pa.table(arrow_dict)
     return arrow_to_pydf(
         arrow_table, schema=schema, schema_overrides=schema_overrides, rechunk=rechunk
