@@ -97,6 +97,12 @@ def test_init_dict() -> None:
     assert df.schema == dfe.schema
     assert len(dfe) == 0
 
+    # empty nested objects
+    for empty_val in [None, "", {}, []]:  # type: ignore[var-annotated]
+        test = [{"field": {"sub_field": empty_val, "sub_field_2": 2}}]
+        df = pl.DataFrame(test, schema={"field": pl.Object})
+        assert df.to_dict(False)["field"][0] == test[0]["field"]
+
 
 def test_init_dataclasses_and_namedtuple() -> None:
     from dataclasses import dataclass
@@ -263,6 +269,7 @@ def test_init_ndarray(monkeypatch: Any) -> None:
     df = pl.DataFrame({"a": np.arange(5, dtype=np.int64).reshape(1, -1)})
     assert df.dtypes == [pl.List(pl.Int64)]
     assert df.shape == (1, 1)
+
     df = pl.DataFrame({"a": np.arange(10, dtype=np.int64).reshape(2, -1)})
     assert df.dtypes == [pl.List(pl.Int64)]
     assert df.shape == (2, 1)
@@ -351,8 +358,15 @@ def test_init_series() -> None:
     assert df.rows() == [(1,), (2,), (3,)]
     assert df.schema == {"a": pl.UInt32}
 
-    # nested list
-    assert pl.Series([[[2, 2]]]).dtype == pl.List(pl.List(pl.Int64))
+    # nested list, with/without explicit dtype
+    s1 = pl.Series([[[2, 2]]])
+    assert s1.dtype == pl.List(pl.List(pl.Int64))
+
+    s2 = pl.Series([[[2, 2]]], dtype=pl.List(pl.List(pl.UInt8)))
+    assert s2.dtype == pl.List(pl.List(pl.UInt8))
+
+    s3 = pl.Series(dtype=pl.List(pl.List(pl.UInt8)))
+    assert s3.dtype == pl.List(pl.List(pl.UInt8))
 
     # numpy data containing NaN values
     s0 = pl.Series("n", [1.0, 2.5, float("nan")])
@@ -510,23 +524,24 @@ def test_init_records_schema_order() -> None:
     ]
     lookup = {"a": 1, "b": 2, "c": 3, "d": 4, "e": None}
 
-    # ensure field values are loaded according to the declared schema order
-    for _ in range(8):
-        shuffle(data)
-        shuffle(cols)
+    for constructor in (pl.from_dicts, pl.DataFrame):
+        # ensure field values are loaded according to the declared schema order
+        for _ in range(8):
+            shuffle(data)
+            shuffle(cols)
 
-        df = pl.from_dicts(dicts=data, schema=cols)
+            df = constructor(data, schema=cols)  # type: ignore[operator]
+            for col in df.columns:
+                assert all(value in (None, lookup[col]) for value in df[col].to_list())
+
+        # have schema override inferred types, omit some columns, add a new one
+        schema = {"a": pl.Int8, "c": pl.Int16, "e": pl.Int32}
+        df = constructor(data, schema=schema)  # type: ignore[operator]
+
+        assert df.schema == schema
         for col in df.columns:
             assert all(value in (None, lookup[col]) for value in df[col].to_list())
 
-    # have schema override inferred types, omit some columns, add a new one
-    schema = {"a": pl.Int8, "c": pl.Int16, "e": pl.Int32}
-    df = pl.from_dicts(dicts=data, schema=schema)
-
-    assert df.schema == schema
-    for col in df.columns:
-        assert all(value in (None, lookup[col]) for value in df[col].to_list())
-
 
 def test_init_only_columns() -> None:
     df = pl.DataFrame(schema=["a", "b", "c"])
@@ -784,6 +799,18 @@ def test_from_records_nullable_structs() -> None:
             ],
         }
 
+    # check initialisation without any records
+    df = pl.DataFrame(schema=schema)
+    dict_schema = dict(schema)
+
+    assert df.to_dict(False) == {"id": [], "items": []}
+    assert df.schema == dict_schema
+
+    s = pl.Series("items", dtype=dict_schema["items"])
+    assert s.to_frame().to_dict(False) == {"items": []}
+    assert s.dtype == dict_schema["items"]
+    assert s.to_list() == []
+
 
 def test_from_categorical_in_struct_defined_by_schema() -> None:
     df = pl.DataFrame(
@@ -798,3 +825,84 @@ def test_from_categorical_in_struct_defined_by_schema() -> None:
     out = df.unnest("a")
     assert out.schema == {"value": pl.Categorical, "counts": pl.UInt32}
     assert out.to_dict(False) == {"value": ["foo", "bar"], "counts": [1, 2]}
+
+
+def test_nested_schema_construction() -> None:
+    schema = {
+        "node_groups": pl.List(
+            pl.Struct(
+                [
+                    pl.Field("parent_node_group_id", pl.UInt8),
+                    pl.Field(
+                        "nodes",
+                        pl.List(
+                            pl.Struct(
+                                [
+                                    pl.Field("name", pl.Utf8),
+                                    pl.Field(
+                                        "sub_nodes",
+                                        pl.List(
+                                            pl.Struct(
+                                                [
+                                                    pl.Field("internal_id", pl.UInt64),
+                                                    pl.Field("value", pl.UInt32),
+                                                ]
+                                            )
+                                        ),
+                                    ),
+                                ]
+                            )
+                        ),
+                    ),
+                ]
+            )
+        )
+    }
+    df = pl.DataFrame(
+        {
+            "node_groups": [
+                [{"nodes": []}, {"nodes": [{"name": "", "sub_nodes": []}]}],
+            ]
+        },
+        schema=schema,
+    )
+    assert df.schema == schema
+    assert df.to_dict(False) == {
+        "node_groups": [
+            [
+                {"parent_node_group_id": None, "nodes": []},
+                {
+                    "parent_node_group_id": None,
+                    "nodes": [{"name": "", "sub_nodes": []}],
+                },
+            ]
+        ]
+    }
+
+    schema = {
+        "node_groups": pl.List(
+            pl.Struct(
+                [
+                    pl.Field(
+                        "nodes",
+                        pl.List(
+                            pl.Struct(
+                                [pl.Field("name", pl.Utf8), pl.Field("time", pl.UInt32)]
+                            )
+                        ),
+                    )
+                ]
+            )
+        )
+    }
+    df = pl.DataFrame(
+        [
+            {"node_groups": [{"nodes": [{"name": "a", "time": 0}]}]},
+            {"node_groups": [{"nodes": []}]},
+        ],
+        schema=schema,
+    )
+    assert df.schema == schema
+    assert df.to_dict(False) == {
+        "node_groups": [[{"nodes": [{"name": "a", "time": 0}]}], [{"nodes": []}]]
+    }
